@@ -1,6 +1,6 @@
 package Geo::Coder::OpenCage;
 # ABSTRACT: Geocode coordinates and addresses with the OpenCage Geocoder
-$Geo::Coder::OpenCage::VERSION = '0.30';
+$Geo::Coder::OpenCage::VERSION = '0.31';
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ use HTTP::Tiny;
 use JSON::MaybeXS;
 use URI;
 # FIXME - must be a way to get this from dist.ini?
-my $version = 0.30;
+my $version = 0.31;
 my $ua_string;
 
 sub new {
@@ -27,7 +27,7 @@ sub new {
         api_key => $params{api_key},
         ua      => $ua,
         json    => JSON::MaybeXS->new(utf8 => 1),
-        url     => URI->new('https://api.opencagedata.com/geocode/v1/json/'),
+        url     => URI->new('https://api.opencagedata.com/geocode/v1/json'),
     };
 
     return bless $self, $class;
@@ -85,11 +85,16 @@ sub geocode {
         }
     }
 
-    my $URL = $self->{url}->clone();
-    $URL->query_form(
-        key => $self->{api_key},
-        %params,
-    );
+    $params{key} = $self->{api_key};
+    
+    # sort the params for better cachability
+    my @final_params;
+    foreach my $k (sort keys %params){
+        push(@final_params, $k => $params{$k})
+        
+    }
+    my $URL = $self->{url}->clone();    
+    $URL->query_form(\@final_params);
 
     my $response = $self->{ua}->get($URL);
 
@@ -136,7 +141,7 @@ Geo::Coder::OpenCage - Geocode coordinates and addresses with the OpenCage Geoco
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
